# Jupyter Community Call 07/26

**Date:** July 26, 2022, at 8am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-07-26/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)** 

**[YouTube](https://youtu.be/D6HvNONkhlE)**

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make short announcements (without a need for discussion). 

* **Darian** Governance update: Executive Council, Software Steering Council, Distinguished Contributors
* **Darian** [Lumino 2](https://github.com/jupyterlab/lumino/pull/319)
* **rcthomas** Reminder on Github 2FA for Jupyter Project developers
    * https://blog.jupyter.org/requiring-2fa-for-jupyter-github-organizations-ad15507da9b1
* **nick** [voila-dashboards](https://github.com/voila-dashboards/voila/pull/846) almost works with lab (no more cdnjs/unpkg, etc.)
* **fcollonval** JupyterLab 3.4.4 released - [Changelog](https://github.com/jupyterlab/jupyterlab/releases/tag/v3.4.4)
* **Isabela** JupyterLab accessibility calls are still happening, and everyone is welcome. Our next call is tomorrow at 10:15am Pacific!
* **nick** [ipywidgets latest docs](https://ipywidgets.readthedocs.io/en/latest/) now include jupyterlite demos

## Agenda Items

* **Isabela** Favorite community call memories/what you want next
    * Demos of work people are building on top of Jupyter (but not sales pitches)
    * "Pie"
    * Themes for calls!
    * Lightning talk length of share (right now we have one minute or ten)
    * "live demos are always good even if they're incomplete"
    * "I'd like people to report a new thing they learned "today I learned" using a Jupyter notebook recently"
    * Sign up sheet to mix up hosts! Good for everyone to get experience and can bring in new energy.
    * Recognize testers 
    * Once a quarter: "here's four ways you can contribute" as a recurring topic so people get reminded and don't have to watch the back catalog to hear it (or a list of projects to contribute to)

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [The New Soul Vegetarian Cookbook](https://www.amazon.com/New-Soul-Vegetarian-Cookbook/dp/0942683137 https://www.amazon.com/Grit-Cookbook-World-Wise-Down-Home-Recipes/dp/1556526482)

## Attendees

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
| Frederic Collonval | QuantStack | @fcollonval |
| Simon Li | University of Dundee | @manics |
| A. T. Darian | QuantStack | @afshin |
| Wayne Decatur | Upstate University | @fomightez |
| Rollin Thomas | NERSC | @rcthomas |
| Jeremy Tuloup | QuantStack  | @jtpio |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 4 more.